<span>
  <img src="https://raw.githubusercontent.com/RxAI-dev/rxlm/refs/heads/main/assets/logo/logo_rxai_v2.png" width="400" />
  <img src="https://raw.githubusercontent.com/RxAI-dev/rxlm/refs/heads/main/assets/logo/logo_rxnn_v2.png" width="400" />
</span>

# Reactive AI - RxLM: Reactive Language Models
## Part of Reactive Neural Networks (RxNN) Platform Ecosystem

> ### IMPORTANT LICENSE NOTICE - FREE & OPEN ONLY FOR NON-COMMERCIAL USAGE
> This framework (RxLM) and all the RxNN Platform Ecosystem is licensed under the **Reactive AI Framework License (RAFL) v1.0** (on bottom of the README),
> that's enabling free and open access only for non-commercial usage. Any commercial usage of the framework and derivatives require
> separate "Reactive AI Commercial License Agreement".
> 
> By accessing, using, downloading and copying/forking this framework, you're implicitly stating that you agree with the license terms.
> 
> Training and publishing the models using RxLM Framework and Reactive Transformer (RxT) is considered as usage and require
> licensing the model under the **Reactive AI Model & Architecture License (RAML) v1.0** (on bottom of the README).

RxNN is AI/Deep Learning development platform made for Reactive Neural Networks and Event-driven AI, introduced by Reactive AI.

### Coming soon
